@@ -17,9 +17,6 @@ require 'tmail/mailp'
 class HeaderField
 
   def initialize( fname, fbody )
-    fname.must String
-    fbody.must String
-
     @name = fname
     fbody.strip!
     @body = fbody
@@ -136,7 +133,6 @@ class StringH < HeaderField
   end
 
   def body=( str )
-    str.must String
     @body = str
     @deced = nil
   end
@@ -218,6 +214,11 @@ class UnknownH < StructH
     @deced == oth.body
   end
 
+  private
+
+  def parse
+  end
+
 end
 
 
@@ -230,7 +231,6 @@ class DateH < StructH
   property :date, Time, true, false
 
   def date=( arg )
-    arg.must Time
     @date = arg.localtime
   end
 
@@ -308,8 +308,6 @@ class << DateH
 
 
   def t2s( tim )
-    tim.must Time
-
     ret = tim.strftime( "%a, #{tim.mday} %b %Y %X " )
 
     # Time#gmtime changes self!!!
@@ -373,7 +371,6 @@ class Mbox
     self.phrase = phr
 
     if ro then
-      ro.must Array
       @routes = ro
     else
       @routes = []
@@ -426,13 +423,8 @@ end   # class Mbox
 class AddrGroup < DelegateClass( Array )
 
   def initialize( name, arg = nil )
-    @name = (name.must String)
-
-    if arg then
-      super( arg.must(Array).dup )
-    else
-      super( [] )
-    end
+    @name = name
+    super arg || []
   end
 
 
@@ -666,7 +658,6 @@ class MsgidH < StructH
   MSGID = /<[^\@>]+\@[^>\@]+>/o
 
   def MsgidH.msgid?( str )
-    str.must String
     MSGID === str
   end
 
@@ -785,7 +776,6 @@ class CEncodingH < StructH
   property :encoding, :String, true, false
 
   def encoding=( enc )
-    enc.must String
     @encoding = enc
   end
 
